conf change: s/set-point/setpoint/

Remove the dash from set-point, such that it's one word: setpoint.

Change-Id: I4c3033f3c2432a53d850e8f5defbe2ac1510daf8
Signed-off-by: Patrick Venture <venture@google.com>
diff --git a/pid/zone.cpp b/pid/zone.cpp
index cc135bf..b6bdba0 100644
--- a/pid/zone.cpp
+++ b/pid/zone.cpp
@@ -118,18 +118,18 @@
     }
 
     /*
      * If the maximum RPM set-point output is below the minimum RPM
      * set-point, set it to the minimum.
      */
     max = std::max(getMinThermalRPMSetpoint(), max);
 
 #ifdef __TUNING_LOGGING__
     /*
-     * We received no set-points from thermal sensors.
+     * We received no setpoints from thermal sensors.
      * This is a case experienced during tuning where they only specify
      * fan sensors and one large fan PID for all the fans.
      */
-    static constexpr auto setpointpath = "/etc/thermal.d/set-point";
+    static constexpr auto setpointpath = "/etc/thermal.d/setpoint";
     try
     {
         std::ifstream ifs;
@@ -139,7 +139,7 @@
             int value;
             ifs >> value;
 
             /* expecting RPM set-point, not pwm% */
             max = static_cast<double>(value);
         }
     }
@@ -118,18 +118,18 @@
 
     /*
-     * If the maximum RPM set-point output is below the minimum RPM
-     * set-point, set it to the minimum.
+     * If the maximum RPM setpoint output is below the minimum RPM
+     * setpoint, set it to the minimum.
      */
     max = std::max(getMinThermalRPMSetpoint(), max);
@@ -139,7 +139,7 @@
             ifs >> value;
 
-            /* expecting RPM set-point, not pwm% */
+            /* expecting RPM setpoint, not pwm% */
             max = static_cast<double>(value);
         }